@@ -2,16 +2,23 @@ import warnings
 from functools import lru_cache
 
 from django.conf import settings
+from django.core.exceptions import ImproperlyConfigured
 from django.forms.widgets import MediaDefiningClass
 from django.template.base import Node, TokenType
 from django.template.loader import get_template
 from django.utils.safestring import mark_safe
 
 # Allow "component.AlreadyRegistered" instead of having to import these everywhere
-from django_components.component_registry import AlreadyRegistered, ComponentRegistry, NotRegistered  # noqa
+from django_components.component_registry import (  # noqa
+    AlreadyRegistered,
+    ComponentRegistry,
+    NotRegistered,
+)
 
-TEMPLATE_CACHE_SIZE = getattr(settings, "COMPONENTS", {}).get('TEMPLATE_CACHE_SIZE', 128)
-ACTIVE_SLOT_CONTEXT_KEY = '_DJANGO_COMPONENTS_ACTIVE_SLOTS'
+TEMPLATE_CACHE_SIZE = getattr(settings, "COMPONENTS", {}).get(
+    "TEMPLATE_CACHE_SIZE", 128
+)
+ACTIVE_SLOT_CONTEXT_KEY = "_DJANGO_COMPONENTS_ACTIVE_SLOTS"
 
 
 class SimplifiedInterfaceMediaDefiningClass(MediaDefiningClass):
@@ -41,17 +48,23 @@ class SimplifiedInterfaceMediaDefiningClass(MediaDefiningClass):
 
 
 class Component(metaclass=SimplifiedInterfaceMediaDefiningClass):
+    template_name = None
 
     def __init__(self, component_name):
         self._component_name = component_name
         self.instance_template = None
         self.slots = {}
 
-    def context(self):
+    def get_context_data(self):
         return {}
 
-    def template(self, context):
-        raise NotImplementedError("Missing template() method on component")
+    def get_template_name(self, context=None):
+        if not self.template_name:
+            raise ImproperlyConfigured(
+                f"Template name is not set for Component {self.__class__.__name__}"
+            )
+
+        return self.template_name
 
     def render_dependencies(self):
         """Helper function to access media.render()"""
@@ -70,13 +83,19 @@ class Component(metaclass=SimplifiedInterfaceMediaDefiningClass):
 
     @staticmethod
     def slots_in_template(template):
-        return {node.name: node.nodelist for node in template.template.nodelist if Component.is_slot_node(node)}
+        return {
+            node.name: node.nodelist
+            for node in template.template.nodelist
+            if Component.is_slot_node(node)
+        }
 
     @staticmethod
     def is_slot_node(node):
-        return (isinstance(node, Node)
-                and node.token.token_type == TokenType.BLOCK
-                and node.token.split_contents()[0] == "slot")
+        return (
+            isinstance(node, Node)
+            and node.token.token_type == TokenType.BLOCK
+            and node.token.split_contents()[0] == "slot"
+        )
 
     @lru_cache(maxsize=TEMPLATE_CACHE_SIZE)
     def get_processed_template(self, template_name):
@@ -112,7 +131,22 @@ class Component(metaclass=SimplifiedInterfaceMediaDefiningClass):
         return component_template
 
     def render(self, context):
-        template_name = self.template(context)
+        if hasattr(self, "context"):
+            warnings.warn(
+                f"{self.__class__.__name__}: `context` method is deprecated, use `get_context` instead",
+                DeprecationWarning,
+            )
+
+        if hasattr(self, "template"):
+            warnings.warn(
+                f"{self.__class__.__name__}: `template` method is deprecated, \
+                set `template_name` or override `get_template_name` instead",
+                DeprecationWarning,
+            )
+            template_name = self.template(context)
+        else:
+            template_name = self.get_template_name(context)
+
         instance_template = self.get_processed_template(template_name)
         with context.update({ACTIVE_SLOT_CONTEXT_KEY: self.slots}):
             return instance_template.render(context)
